import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_tokens/tokens/senior_colors.dart';

class SeniorColorfulHeaderStructure extends StatefulWidget {
  const SeniorColorfulHeaderStructure({
    Key? key,
    required this.title,
    required this.body,
    this.leading,
    this.actions,
    this.hasTopPadding = true,
    this.hasTopShadow = false,
    this.colors,
  }) : super(
          key: key,
        );

  final Widget title;
  final Widget? leading;
  final List<Widget>? actions;
  final Widget body;
  final bool hasTopPadding;
  final bool hasTopShadow;
  final List<Color>? colors;

  @override
  State<SeniorColorfulHeaderStructure> createState() =>
      _SeniorColorfulHeaderStructureState();
}

class _SeniorColorfulHeaderStructureState
    extends State<SeniorColorfulHeaderStructure> {
  @override
  Widget build(BuildContext context) {
    final mediaQuery = MediaQuery.of(context);
    final cornerRadius = BorderRadius.only(
      topLeft: Radius.circular(
        SeniorRadius.huge,
      ),
      topRight: Radius.circular(
        SeniorRadius.huge,
      ),
    );
    var appBarHeight = kToolbarHeight;
    var topCornersHeight = SeniorRadius.huge + 1;
    var topHeight = mediaQuery.padding.top + appBarHeight + topCornersHeight;

    return Stack(
      children: [
        Container(
          padding: EdgeInsets.zero,
          height: topHeight,
          decoration: BoxDecoration(
            gradient: LinearGradient(
              colors: widget.colors ?? SeniorColors.primaryGradientColors,
            ),
          ),
        ),
        Column(
          children: [
            AppBar(
              leading: widget.leading,
              elevation: 0,
              backgroundColor: Colors.transparent,
              actions: widget.actions,
              title: widget.title,
              centerTitle: false,
              toolbarHeight: appBarHeight,
            ),
            widget.hasTopPadding
                ? AnimatedContainer(
                    duration: kThemeAnimationDuration,
                    height: topCornersHeight,
                    decoration: BoxDecoration(
                      borderRadius: cornerRadius,
                      color: SeniorColors.pureWhite,
                      boxShadow: widget.hasTopShadow
                          ? [
                              BoxShadow(
                                color: Colors.black.withOpacity(0.2),
                                blurRadius: SeniorRadius.medium,
                                offset: Offset(0.0, SeniorRadius.medium),
                              ),
                            ]
                          : [],
                    ),
                  )
                : const SizedBox.shrink(),
            Expanded(
              child: Container(
                height: topCornersHeight,
                decoration: !widget.hasTopPadding
                    ? BoxDecoration(
                        borderRadius: cornerRadius,
                        color: SeniorColors.pureWhite,
                      )
                    : null,
                child: widget.body,
              ),
            ),
          ],
        ),
      ],
    );
  }
}
